# Reproducing Fig. 9: BEC & Raman Calculations for CO₂

## Overview
This folder contains all scripts, data, and models to compute atomic Born effective 
charges (BEC) and Raman tensors for CO₂, both reference and ML-predicted, under 
equilibrium and varying bond lengths.

## 1. Dataset Generation (`0_generate_dataset/`)
- **0_run_md.py**: run MD to sample CO₂ geometries for training and evaluation.

## 2. Compute Per-Atom Equivariants (`1_compute_per_atom_equivariants/`)
- **0_compute.py**: compute atomic BEC & Raman tensors from snapshots.  
- **1_parse_outputs.py**: collate raw outputs and write `.mts` files in `../data`.  
- **Outputs**:  
  - `outputs/{0,…,399}/`: per-geometry-set `bec.npy` & `raman.npy`  
  - `outputs_change_bond_length/{0,…,99}/`: same files for bond-stretched geometries  

## 3. Training & Evaluation (`2_train/`)
- **0_train/**  
  - **lMCoV/** & **MCoV/** pipelines:  
    - `options.yaml`: `metatrain` options file
    - `0_train`: fit model with `metatrain`
    - `1_export`: export model with `metatrain`
    - `model.ckpt`: model checkpoint
    - `outputs/YYYY-MM-DD/HH-MM-SS/`: training indices, checkpoints (`model_{…}.ckpt`), logs  
- **1_eval/**  
  - `0_eval`: run `eval.py`
  - `eval.py`: inference script. Writes ML-predicted `bec` & `raman` files  

## 4. Data (`data/`)
- **Geometries & Trajectories**:  
  - `co2_dataset.xyz`, `co2_pet_mad_trajectory.traj`  
  - `co2_change_bond_length.xyz`  
- **Reference Targets**:  
  - `bec_co2.mts`, `raman_co2.mts`  
  - `bec_co2_change_bond_length.mts`, `raman_co2_change_bond_length.mts`  
- **ML Predictions**:  
  - `lMCoV_predicted_{bec,raman}_co2_change_bond_length.mts`  
  - `MCoV_predicted_{bec,raman}_co2_change_bond_length.mts`  

## 5. Plotting
- **plot.py**: generates comparison Fig. 9.  
- **bec_and_raman_co2.pdf**: final plotted results.
